<?php # $Id: serendipity_lang_en.inc.php 568 2005-10-18 19:01:10Z garvinhicking $
# Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
# All rights reserved.  See LICENSE file for licensing details
# Arabic issue was translated by Way http://www.flyingway.com  UTF-8
/* vim: set sts=4 ts=4 expandtab : */

@define('LANG_CHARSET', 'UTF-8');
@define('DATE_LOCALES', 'Arabic,ar , ar_SA.windows-1256');
@define('DATE_FORMAT_ENTRY', '%A, %B %e. %Y');
@define('DATE_FORMAT_SHORT', '%Y-%m-%d %H:%M');
@define('WYSIWYG_LANG', 'en');
@define('NUMBER_FORMAT_DECIMALS', '2');
@define('NUMBER_FORMAT_DECPOINT', '.');
@define('NUMBER_FORMAT_THOUSANDS', ',');
@define('LANG_DIRECTION', 'rtl');

@define('SERENDIPITY_ADMIN_SUITE', 'حقيبة إدارة المجلة');
@define('HAVE_TO_BE_LOGGED_ON', 'ينوجب عليك التسجيل كي تتمكن من مشاهدة هذه الصفحة');
@define('WRONG_USERNAME_OR_PASSWORD', 'اسم المستخدم أو كلمة المرور غير صحيحة');
@define('APPEARANCE', 'ظهور');
@define('MANAGE_STYLES', 'ادارة الستايلات');
@define('CONFIGURE_PLUGINS', 'تهيئة ملفات الحث - بلوق ان');
@define('CONFIGURATION', 'إعدادت عامة للمجلة');
@define('BACK_TO_BLOG', 'العودة الى المجلة');
@define('LOGIN', 'تسجيل الدخول');
@define('LOGOUT', 'خروج');
@define('LOGGEDOUT', 'تم الخروج');
@define('CREATE', 'انشاء');
@define('SAVE', 'حفظ');
@define('NAME', 'الأسم');
@define('CREATE_NEW_CAT', 'انشاء قسم جديد');
@define('I_WANT_THUMB', 'اريد استخدام الصور المصغرة في مشاركتي');
@define('I_WANT_BIG_IMAGE', 'اريد استخدام صور كبيرة في مشاركتي');
@define('I_WANT_NO_LINK', 'أ{يد عرضها على هئية صور');
@define('I_WANT_IT_TO_LINK', 'اريد عرضها على شكل ارتباط الى هذا الرابط');
@define('BACK', 'عودة');
@define('FORWARD', 'تقديم');
@define('ANONYMOUS', 'مجهول');
@define('NEW_TRACKBACK_TO', 'تم عمل مسار عودة جديد الى');
@define('NEW_COMMENT_TO', 'تم ادراج تعليق جديد الى');
@define('RECENT', 'الجديد ...');
@define('OLDER', 'القديم ...');
@define('DONE', 'تم الاجراء');
@define('WELCOME_BACK', 'مرحبا بعودتك ،');
@define('TITLE', 'العنوان');
@define('DESCRIPTION', 'الوصف');
@define('PLACEMENT', 'تعيين');
@define('DELETE', 'حذف');
@define('SAVE', 'حفظ');
@define('UP', 'أعلى');
@define('DOWN', 'أسفل');
@define('ENTRIES', 'الموضوع');
@define('NEW_ENTRY', 'أنشاء موضوع جديد');
@define('EDIT_ENTRIES', 'تحرير المواضيع');
@define('CATEGORIES', 'أقسام');
@define('WARNING_THIS_BLAHBLAH', "تحذير:\\nيمكن ان تستغرق وقت طويل جداً ان كان هناك صور بدون الصور المصغرة لها");
@define('CREATE_THUMBS', 'أعد بناء الصور المصغرة');
@define('MANAGE_IMAGES', 'ادارة الصور');
@define('NAME', 'الأسم');
@define('EMAIL', 'بريدك الالكتروني');
@define('HOMEPAGE', 'صفحتك أو موقعك المفضل');
@define('COMMENT', 'التعليق');
@define('REMEMBER_INFO', 'تذكر المعلومات؟ ');
@define('SUBMIT_COMMENT', 'ادرج تعليق');
@define('NO_ENTRIES_TO_PRINT', 'لا يوجد مواضيع للطباعة');
@define('COMMENTS', 'تعليقات');
@define('ADD_COMMENT', 'اضافة تعليق');
@define('NO_COMMENTS', 'لا تعليقات');
@define('POSTED_BY', 'حررة بواسطة');
@define('ON', 'تشغيل');
@define('A_NEW_COMMENT_BLAHBLAH', 'تم ادراج تعليق جديد في مدونتك "%s", على هذا الرابط "%s".');
@define('A_NEW_TRACKBACK_BLAHBLAH', 'تم ادراج تعديل على مشاركة في مدونتك "%s".');
@define('NO_CATEGORY', 'لا يوجد تصنيف');
@define('ENTRY_BODY', 'الجزء الاولي من الموضوع');
@define('EXTENDED_BODY', 'الجزء التالي');
@define('CATEGORY', 'تصنيف');
@define('EDIT', 'تحرير');
@define('NO_ENTRIES_BLAHBLAH', 'لم يتم العثور على اي مواضيع جديدة %s' . "\n");
@define('YOUR_SEARCH_RETURNED_BLAHBLAH', 'بحثك عن  %s وجد %s هذه النتائج');
@define('SEARCH_TOO_SHORT', 'يجب أن تكون عملية البحث بكلمة أكثر من 3 أحرف ! ! ! يمكن لك استخدام النجمة * كي تجعل هذه العملية أقصر من 3 أحرف لتتم عملية بحثك عن الكلمات القصيرة');
@define('IMAGE', 'Image');
@define('ERROR_FILE_NOT_EXISTS', 'خطأ: لم يتم أدخال الملف القديم');
@define('ERROR_FILE_EXISTS', 'خطأ : أسم الملف يوجد من قبل أختر أسماً أخر');
@define('ERROR_SOMETHING', 'خطأ: في خطأ ما');
@define('ADDING_IMAGE', 'اضافة صورة...');
@define('THUMB_CREATED_DONE', 'الصورة المصغرة<br/>جاهزة');
@define('ERROR_FILE_EXISTS_ALREADY', 'خطأ! الملف موجود مسبقاً');
@define('ERROR_UNKNOWN_NOUPLOAD', 'حصل خطأ غير معروف! ! ! لم يتمل رفع الملف – من الممكن أن يكون الملف أكبر من حجم الملف لمصرح برفعه ! ! ! أفحص ISP أو قم بتحرير ملف php.ini كي تسمح برفع الملفات الكبيرة');
@define('GO', 'أكمل!');
@define('NEWSIZE', 'المقاس الجديد: ');
@define('RESIZE_BLAHBLAH', '<b>تغيير المقاييس %s</b><p>');
@define('ORIGINAL_SIZE', 'الحجم الاصلي <i>%sx%s</i> pixel');
@define('HERE_YOU_CAN_ENTER_BLAHBLAH', '<p>يمكن لك تغيير قياسات الصورة - ان كنت تريد تغيير قياسات الصورة بأطوال متناسبة - كل ما عليك هو ادخل القياس الجديد في احد الصندوقين ثم أضغط زر Tab -- سوف تعطيك اتماتيكياً الحجم المناسب للقياس الجديد - لذلك الصورة سوف تستمر بشكلها الأصلي و لا تفقد شكل توازنها</p>');
@define('QUICKJUMP_CALENDAR', 'QuickJump Calendar');
@define('QUICKSEARCH', 'بحث سريع');
@define('SEARCH_FOR_ENTRY', 'ابحث عن أي معطيات');
@define('ARCHIVES', 'ارشيف');
@define('BROWSE_ARCHIVES', 'تصفح الارشيف شهريا');
@define('TOP_REFERRER', 'أكثر الزيارات من:');
@define('SHOWS_TOP_SITES', 'أعرض افضل المواقع المرتبطة بمدونتك');
@define('TOP_EXITS', 'اعلى المشاركات');
@define('SHOWS_TOP_EXIT', 'أعرض اعلى الروابط يم الخروج من مدونتك إليه');
@define('SYNDICATION', 'منشور');
@define('SHOWS_RSS_BLAHBLAH', 'أعرض رابط النشر لـ RSS');
@define('ADVERTISES_BLAHBLAH', 'عمل إشهار لمنشأ مدونتك');
@define('HTML_NUGGET', 'HTML Nugget');
@define('HOLDS_A_BLAHBLAH', 'هذه الاجراءات ستظهر في القوائم الجانبية للمدونة');
@define('TITLE_FOR_NUGGET', 'عنوان كتلة العمل');
@define('THE_NUGGET', 'إجراءات بصيغة HTML!');
@define('SYNDICATE_THIS_BLOG', 'يمكنك أخذ نسخة للطباعة بأحدى هذه الصيغ');
@define('YOU_CHOSE', 'اختيارك %s');
@define('IMAGE_ROTATE_LEFT', 'ادر الصورة 90 درجة بأتجاه عقارب الساعة');
@define('IMAGE_ROTATE_RIGHT', 'ادر الصورة 90 درجة بأتجاه عقارب الساعة');
@define('IMAGE_SIZE', 'حجم الصورة');
@define('IMAGE_AS_A_LINK', 'ادخال صورة');
@define('POWERED_BY', 'بواسطة');
@define('TRACKBACKS', 'روابط تعقيبات');
@define('TRACKBACK', 'رابط تعقيب');
@define('NO_TRACKBACKS', 'لا يوجد روابط تعقيب');
@define('TOPICS_OF', 'نموذج المشاركة');
@define('VIEW_FULL', 'عرض كامل');
@define('VIEW_TOPICS', 'عرض المقالات');
@define('AT', 'في');
@define('SET_AS_TEMPLATE', 'ضعة على هيئة قالب');
@define('IN', 'في');
@define('EXCERPT', 'مقتبسات');
@define('TRACKED', 'تعقب');
@define('LINK_TO_ENTRY', 'اربط الى المشاركة');
@define('LINK_TO_REMOTE_ENTRY', 'اربط الى الشاركة البعيدة');
@define('IP_ADDRESS', 'IP-address');
@define('USER', 'مستخدم');
@define('THUMBNAIL_USING_OWN', 'استخدم %s ععلى أنها صورة مصغرة لأنها من الاساس صورة صغيرة');
@define('THUMBNAIL_FAILED_COPY', 'تريد ان تستخدم %s من صالورة المصغرة لها . لكن فشل في عملية النسخ');
@define('AUTHOR', 'الكاتب');
@define('LAST_UPDATED', 'أخر تحديث');
@define('TRACKBACK_SPECIFIC', 'تعقب رابط معين لهذه المشاركة');
@define('DIRECT_LINK', 'ربط مباشر مع هذه المشاركة');
@define('COMMENT_ADDED', 'تم ادراج تعليقاتك بنجاح ');
@define('COMMENT_ADDED_CLICK', 'Click %shere to return%s to the comments, and %shere to close%s this window.');
@define('COMMENT_NOT_ADDED', 'تم إيقاف التعليقات على هذه الموضوع لذلك لم يتم ادراج تعليقك ');
@define('COMMENT_NOT_ADDED_CLICK', 'Click %shere to return%s to the comments, and %shere to close%s this window.');
@define('COMMENTS_DISABLE', 'لا تسمح بالتعليقات على هذا الموضوع');
@define('COMMENTS_ENABLE', 'السماح بالتعليقات على هذا الموضوع');
@define('COMMENTS_CLOSED', 'كاتب الموضوع لم يسمح بالتعليقات على هذا الموضوع');
@define('EMPTY_COMMENT', 'تعليقك لا يحتوي على أي شيء الرجاء  %s العودة إلى %s و المحاولة مرة أخرى');
@define('ENTRIES_FOR', 'موضوع من %s');
@define('DOCUMENT_NOT_FOUND', 'لم يتم العثور على هذه الوثيقة %s');
@define('USERNAME', 'أسم المستخدم');
@define('PASSWORD', 'كلمة المرور');
@define('AUTOMATIC_LOGIN', 'حفظ المعلومات');
@define('SERENDIPITY_INSTALLATION', 'اعدادات تركيب المجلة');
@define('LEFT', 'يسار');
@define('RIGHT', 'يمين');
@define('HIDDEN', 'مخفي');
@define('REMOVE_TICKED_PLUGINS', 'ابعد البوقات المختارة');
@define('SAVE_CHANGES_TO_LAYOUT', 'حفظ التغييرات على التنسيق');
@define('COMMENTS_FROM', 'تعليقات من');
@define('ERROR', 'خطأ');
@define('ENTRY_SAVED', 'تم حفظ مشاركتك');
@define('DELETE_SURE', 'هل انت متأكد من حذف %s حذف تام - لن يكون بمقدورك استرجاعة');
@define('NOT_REALLY', 'لا');
@define('DUMP_IT', 'نعم');
@define('RIP_ENTRY', 'تم حذف %s ');
@define('CATEGORY_DELETED_ARTICLES_MOVED', 'Category #%s deleted. Old articles moved to category #%s.');
@define('CATEGORY_DELETED', 'التصنيف #%s تم حذفة.');
@define('INVALID_CATEGORY', 'لم يتم أعطاء أي تصنيف كي يحذف');
@define('CATEGORY_SAVED', 'تم حفظ الأقسام');
@define('SELECT_TEMPLATE', 'أختر القالب الذي تود أستخدامة على المجلة');
@define('ENTRIES_NOT_SUCCESSFULLY_INSERTED', 'لم يتم ادراج الموضوع بنجاح ! ! !');
@define('MT_DATA_FILE', 'قابل لنقل ملف المعلومات');
@define('FORCE', 'بالقوة');
@define('CREATE_AUTHOR', 'انشاء محرر \'%s\'.');
@define('CREATE_CATEGORY', 'انشاء صيغة \'%s\'.');
@define('MYSQL_REQUIRED', 'You must have the MySQL extension in order to perform this action.');
@define('COULDNT_CONNECT', 'لا يمكن الاتصال بقاعدة البيانات: %s.');
@define('COULDNT_SELECT_DB', 'لا يمكن أختيار معلومات قاعدة البيانات: %s.');
@define('COULDNT_SELECT_USER_INFO', 'لا يمكن أختيار معلومات العضو: %s.');
@define('COULDNT_SELECT_CATEGORY_INFO', 'لا يمكن أختيار معلومات التصنيف: %s.');
@define('COULDNT_SELECT_ENTRY_INFO', 'لا يمكن أختيار معلومات الموضوع: %s.');
@define('COULDNT_SELECT_COMMENT_INFO', 'لا يمكن أختيار معلومات التعليق: %s.');
@define('YES', 'نعم');
@define('NO', 'لا');
@define('USE_DEFAULT', 'أفتراضي');
@define('CHECK_N_SAVE', 'فحص و حفظ');
@define('DIRECTORY_WRITE_ERROR', 'غير قادر بالكتابة في المجلد %s الرجاء التأكد من التصاريح');
@define('DIRECTORY_CREATE_ERROR', 'المجلد %s لم يتم انشاء المجلد الرجاء قم بأنشاءة يدوياً');
@define('DIRECTORY_RUN_CMD', '&nbsp;-&gt; run <i>%s %s</i>');
@define('CANT_EXECUTE_BINARY', 'Cannot execute the %s binary');
@define('FILE_WRITE_ERROR', 'Cannot write to file %s.');
@define('FILE_CREATE_YOURSELF', 'الرجاء أن تنشئ الملف بنفسك او قم بفحص التصاريح للمجلدات ');
@define('COPY_CODE_BELOW', '<br />* قم بنسخ الكود الموجود بالاسفل و ضعه  %s في %s المجلد:<b><pre>%s</pre></b>' . "\n");
@define('WWW_USER', 'Change www to the user apache runs as (e.g. nobody).');
@define('BROWSER_RELOAD', 'Once you have done this, hit your browser\'s "reload" button.');
@define('DIAGNOSTIC_ERROR', 'تم أكتشاف بعض الاخطاء خلال عملية تفحص البيانات المدخلة:');
@define('SERENDIPITY_NOT_INSTALLED', 'Serendipity is not yet installed. Please <a href="%s">install</a> it now.');
@define('INCLUDE_ERROR', 'serendipity error: could not include %s - exiting.');
@define('DATABASE_ERROR', 'serendipity error: unable to connect to database - exiting.');
@define('CREATE_DATABASE', 'Creating default database setup...');
@define('ATTEMPT_WRITE_FILE', 'Attempting to write %s file...');
@define('WRITTEN_N_SAVED', 'تم تعديل و حفظ الإعدادات');
@define('IMAGE_ALIGNMENT', 'محاذات الصورة');
@define('ENTER_NEW_NAME', 'أدخل أسم جديد لـ: ');
@define('RESIZING', 'تغير الحجم');
@define('RESIZE_DONE', 'تم (تغيير قياسات %s صورة).');
@define('SYNCING', 'ضبط قاعدة البيانات مع مجلد الصور');
@define('SYNC_DONE', 'Done (ضبط %s الصور).');
@define('FILE_NOT_FOUND', 'لم يتم إيجاد الملف <b>%s</b>, من الممكن أن يكون قد حذف؟');
@define('ABORT_NOW', 'توقف الآن');
@define('REMOTE_FILE_NOT_FOUND', 'File was not located on the remote server, are you sure the URL: <b>%s</b> is correct?');
@define('FILE_FETCHED', '%s fetched as %s');
@define('FILE_UPLOADED', 'الملف %s تم رفعة بنجاج بـ %s');
@define('WORD_OR', 'Or');
@define('SCALING_IMAGE', 'Scaling %s to %s x %s px');
@define('KEEP_PROPORTIONS', 'المحافظة على تناسب المقاسات');
@define('REALLY_SCALE_IMAGE', 'هل انت متأكد من تغيير حجم الصورة ! ! أنتبه ! ! لا يوجد تراجع بعد تغيير المقاسات');
@define('TOGGLE_ALL', 'أضغط هنا لعرض جميع الخيارات');
@define('TOGGLE_OPTION', 'Toggle option');
@define('SUBSCRIBE_TO_THIS_ENTRY', 'الاشتراك في هذا الموضوع');
@define('UNSUBSCRIBE_OK', "%s الان لا يمكن الاشتراك في هذا الموضوع");
@define('NEW_COMMENT_TO_SUBSCRIBED_ENTRY', 'New comment to subscribed entry "%s"');
@define('SUBSCRIPTION_MAIL', "Hello %s,\n\nA new comment was made to the entry you are monitoring on \"%s\", entitled \"%s\"\nThe name of the poster is: %s\n\nYou can find the entry here: %s\n\nYou can unsubscribe by clicking on this link: %s\n");
@define('SUBSCRIPTION_TRACKBACK_MAIL', "Hello %s,\n\nA new trackback was added to the entry you are monitoring on \"%s\", entitled \"%s\"\nThe name of the poster is: %s\n\nYou can find the entry here: %s\n\nYou can unsubscribe by clicking on this link: %s\n");
@define('SIGNATURE', "\n-- \n%s is powered by Serendipity.\nThe best blog around, you can use it too.\nCheck out <http://s9y.org> to find out how.");
@define('SYNDICATION_PLUGIN_091', 'RSS 0.91 feed');
@define('SYNDICATION_PLUGIN_10', 'RSS 1.0 feed');
@define('SYNDICATION_PLUGIN_20', 'RSS 2.0 feed');
@define('SYNDICATION_PLUGIN_20c', 'RSS 2.0 comments');
@define('SYNDICATION_PLUGIN_ATOM03', 'ATOM 0.3 feed');
@define('SYNDICATION_PLUGIN_MANAGINGEDITOR', 'حقل "محرر الاعدادات"');
@define('SYNDICATION_PLUGIN_WEBMASTER',  'حقل "المشرف العام"');
@define('SYNDICATION_PLUGIN_BANNERURL', 'Image for the RSS feed');
@define('SYNDICATION_PLUGIN_BANNERWIDTH', 'عرض الصورة');
@define('SYNDICATION_PLUGIN_BANNERHEIGHT', 'طول الصورة');
@define('SYNDICATION_PLUGIN_WEBMASTER_DESC',  'البريد الالكتروني للمشرف العام للمدونة. (فارغ: مخفي) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_MANAGINGEDITOR_DESC', 'البريد الالكتروني للمحرر ان وجد - ان كان فارغ سوف يكون الحقل مخفي [RSS 2.0]');
@define('SYNDICATION_PLUGIN_BANNERURL_DESC', 'رابط صورة من نوع GIF/JPEG/PNG اذا كانت موجودة كي تستخدم شعار للمدونة - ان تركته فارغ سوف يتم اختيار الشعار الافتراضي');
@define('SYNDICATION_PLUGIN_BANNERWIDTH_DESC', 'in pixels, max. 144');
@define('SYNDICATION_PLUGIN_BANNERHEIGHT_DESC', 'in pixels, max. 400');
@define('SYNDICATION_PLUGIN_TTL', 'Field "ttl" (time-to-live)');
@define('SYNDICATION_PLUGIN_TTL_DESC', 'Amount of minutes after which your blog should not be cached any more by foreign sites/applications (empty: hidden) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_PUBDATE', 'حقل تاريخ النشر');
@define('SYNDICATION_PLUGIN_PUBDATE_DESC', 'Should the "pubDate"-field be embedded for a RSS-channel, to show the date of the latest entry?');
@define('CONTENT', 'محتوى');
@define('TYPE', 'نوع');
@define('DRAFT', 'مسودة');
@define('PUBLISH', 'نشر');
@define('PREVIEW', 'مشاهدة المشاركة');
@define('DATE', 'التاريخ');
@define('DATE_FORMAT_2', 'Y-m-d H:i'); // Needs to be ISO 8601 compliant for date conversion!
@define('DATE_INVALID', 'تحذير: صيغة الوقت التي أخترتها غير صحيحة ! ! يجب أن تكون الصيغة مماثل  YYYY-MM-DD HH:MM');
@define('CATEGORY_PLUGIN_DESC', 'عرض قائمة بالأقسام الموجودة');
@define('ALL_AUTHORS', 'جميع المستخدمين');
@define('CATEGORIES_TO_FETCH', 'جلب للأقسام');
@define('CATEGORIES_TO_FETCH_DESC', 'قم بجلب أقسام من أي الكتاب؟');
@define('PAGE_BROWSE_ENTRIES', 'الصفحة رقم %s من %s, مجموع %s مواضيع');
@define('PREVIOUS_PAGE', 'الصفحة السابقة');
@define('NEXT_PAGE', 'الصفحة التالية');
@define('ALL_CATEGORIES', 'جميع التصانيف');
@define('DO_MARKUP', 'إجراءات تحويل الاكواد');
@define('GENERAL_PLUGIN_DATEFORMAT', 'صيغة التاريخ');
@define('GENERAL_PLUGIN_DATEFORMAT_BLAHBLAH', 'صيغة ادخال التاريخ الحقيقي في PHPs strftime() variables. (Default: "%s")');
@define('ERROR_TEMPLATE_FILE', 'غير قادر على فتح ملف القالب. الرجاء تحديث المجلة');
@define('ADVANCED_OPTIONS', 'خيارات متقدمة');
@define('EDIT_ENTRY', 'تحرير الموضوع');
@define('HTACCESS_ERROR', 'To check your local webserver installation, serendipity needs to be able to write the file ".htaccess". This was not possible because of permission errors. Please adjust the permissions like this: <br />&nbsp;&nbsp;%s<br />and reload this page.');
@define('SIDEBAR_PLUGINS', 'شريط الادوات الجانبي للبلق ان');
@define('EVENT_PLUGINS', 'بلوقات لوظائف واحداث');
@define('SORT_ORDER', 'طريقة الترتيب');
@define('SORT_ORDER_NAME', 'أسم الملف');
@define('SORT_ORDER_EXTENSION', 'نوعية الملف');
@define('SORT_ORDER_SIZE', 'حجم الملف');
@define('SORT_ORDER_WIDTH', 'عرض الصورة');
@define('SORT_ORDER_HEIGHT', 'ارتفاع الصورة');
@define('SORT_ORDER_DATE', 'تاريخ الرفع');
@define('SORT_ORDER_ASC', 'ترتيب تصاعدي');
@define('SORT_ORDER_DESC', 'ترتيب تنازلي');
@define('THUMBNAIL_SHORT', 'صورة مصغرة');
@define('ORIGINAL_SHORT', 'Orig.');
@define('APPLY_MARKUP_TO', 'ضع إشارة إلى %s');
@define('CALENDAR_BEGINNING_OF_WEEK', 'بداية الاسبوع');
@define('SERENDIPITY_NEEDS_UPGRADE', 'Serendipity has detected that your currently installed Serendipity version is %s. It seems you are attempting to upgrade to version %s, so you need to <a href="%s">click here</a> to continue the upgrade process.');
@define('SERENDIPITY_UPGRADER_WELCOME', 'Hi, and welcome to the Serendipity upgrade agent.');
@define('SERENDIPITY_UPGRADER_PURPOSE', 'I am here to help you upgrade your Serendipity %s installation.');
@define('SERENDIPITY_UPGRADER_WHY', 'You are seeing this message because you have just installed Serendipity %s, but have not yet upgraded your database installation to fit this version');
@define('SERENDIPITY_UPGRADER_DATABASE_UPDATES', 'Database updates (%s)');
@define('SERENDIPITY_UPGRADER_FOUND_SQL_FILES', 'I have found the following .sql files which needs to be run before you can continue normal operation of Serendipity');
@define('SERENDIPITY_UPGRADER_VERSION_SPECIFIC',  'Version specific tasks');
@define('SERENDIPITY_UPGRADER_NO_VERSION_SPECIFIC', 'No version specific tasks found');
@define('SERENDIPITY_UPGRADER_PROCEED_QUESTION', 'Do you wish me to perform the above tasks?');
@define('SERENDIPITY_UPGRADER_PROCEED_ABORT', 'No, I will run them manually');
@define('SERENDIPITY_UPGRADER_PROCEED_DOIT', 'Yes, please do so');
@define('SERENDIPITY_UPGRADER_NO_UPGRADES', 'It appears you do not need any upgrades run');
@define('SERENDIPITY_UPGRADER_CONSIDER_DONE', 'Consider Serendipity upgraded');
@define('SERENDIPITY_UPGRADER_YOU_HAVE_IGNORED', 'You have ignored the upgrade stage of Serendipity, please make sure your database is correctly installed, and scheduled functions are run');
@define('SERENDIPITY_UPGRADER_NOW_UPGRADED', 'Your Serendipity installation is now upgraded to version %s');
@define('SERENDIPITY_UPGRADER_RETURN_HERE', 'You can return to your blog by clicking %shere%s');
@define('MANAGE_USERS', 'إدارة الإعضاء');
@define('CREATE_NEW_USER', 'انشاء مستخدم جديد');
@define('CREATE_NOT_AUTHORIZED', 'لا يمكن لك أن تطور او تعدل على مستخدم لديه نفس مستوك في الصلاحيات');
@define('CREATE_NOT_AUTHORIZED_USERLEVEL', 'لا يمكن لك أن تنشئ مستخدم جديد يمتلك صلاحيات أكبر من صلاحياتك');
@define('CREATED_USER', 'تم انشاءة %s المستخدم الجديد');
@define('MODIFIED_USER', 'تم تغيير خصائص هذه المستخدم %s');
@define('USER_LEVEL', 'Userlevel');
@define('DELETE_USER', 'هل انت جاد في حذف المستخدم  #%d %s ؟ هذا يعني عدم ظهور أي موضوع كتبه أو شارك في تحريرة ! ! ! انتبه لا تضيع مدونتك');
@define('DELETED_USER', 'بواسطة المستخدم #%d %s تم حذفه.');
@define('LIMIT_TO_NUMBER', 'كم مادة يمكن عرضها؟');
@define('ENTRIES_PER_PAGE', 'المواضيع في كل صفحة');
@define('XML_IMAGE_TO_DISPLAY', 'XML Button');
@define('XML_IMAGE_TO_DISPLAY_DESC','Links to XML Feeds will be displayed by this image. Leave empty for default, enter \'none\' to disable.');

@define('DIRECTORIES_AVAILABLE', 'فيالقائمة يوجد مجلدات فرعيه. يمكن لك أن تضغط على أسم ! !  أي منها لإنشاء مجلد جديد بنفس الهيكل هذا');
@define('ALL_DIRECTORIES', 'جميع المجلدات');
@define('MANAGE_DIRECTORIES', 'إدارة المجلدات');
@define('DIRECTORY_CREATED', 'المجلد <strong>%s</strong> تم انشاءة');
@define('PARENT_DIRECTORY', 'المجلد الرئيسي أو الاب');
@define('CONFIRM_DELETE_DIRECTORY', 'هل انت متأكد من نقل جميع محتويات المجلد  %s?');
@define('ERROR_NO_DIRECTORY', 'خطأ: لم يتم إدخال المجلد %s ');
@define('CHECKING_DIRECTORY', 'تفحص الملفات في المجلد %s ');
@define('DELETING_FILE', 'حذف الملف %s ...');
@define('ERROR_DIRECTORY_NOT_EMPTY', 'Could not remove non-empty directory. Check the "force deletion" checkbox if you want to remove those files as well, and then submit again. Existing files are:');
@define('DIRECTORY_DELETE_FAILED', 'Deletion of directory %s failed. Check permissions or messages above.');
@define('DIRECTORY_DELETE_SUCCESS', 'تم حذف المجلد %s بنجاح');
@define('SKIPPING_FILE_EXTENSION', 'تجاهل الملفات: التي بدون وصل تعريف %s.');
@define('SKIPPING_FILE_UNREADABLE', 'تجاهل الملفات: %s غير المقروأة');
@define('FOUND_FILE', 'تم العثور على ملف جديد أو محدث: %s');
@define('ALREADY_SUBCATEGORY', 'ان %s قسم فرعي موجود من %s');
@define('PARENT_CATEGORY', 'المجلد الرئيسي');
@define('IN_REPLY_TO', 'في الرد على');
@define('TOP_LEVEL', 'مستوى أعلى');
@define('SYNDICATION_PLUGIN_GENERIC_FEED', '%s feed');
@define('PERMISSIONS', 'الصلاحيات');
@define('SETTINGS_SAVED_AT', 'تم حفظ الاعدادات الجديدة في  %s');

/* DATABASE SETTINGS */
@define('INSTALL_CAT_DB', 'أعدادات قاعدة البيانات');
@define('INSTALL_CAT_DB_DESC', 'يمكنك هنا ان تدرج جميع معلومات قاعدت البيانات الخاصة بك.مدوناتنا المهوبة بحاجة الى هذه المعلومات كي تعمل');
@define('INSTALL_DBTYPE', 'نوع قاعدة البيانات');
@define('INSTALL_DBTYPE_DESC', 'نوع قاعدة البيانات');
@define('INSTALL_DBHOST', 'مستضيف قاعدة البيانات');
@define('INSTALL_DBHOST_DESC', 'اسم السيرفر المستضيف لقاعدة البيانات');
@define('INSTALL_DBUSER', 'اسم مستخدم قاعدة البيانات');
@define('INSTALL_DBUSER_DESC', 'اسم المستخدم الذي يمكنه الاتصال في قاعدة البيانات');
@define('INSTALL_DBPASS', 'كلمة المرور لقاعدة البيانات');
@define('INSTALL_DBPASS_DESC', 'كلمة المرور لقاعدة البيانات خاصة بهذا المستخدم');
@define('INSTALL_DBNAME', 'اسم قاعدة البيانات');
@define('INSTALL_DBNAME_DESC', 'أسم قاعدة البيانات');
@define('INSTALL_DBPREFIX', 'بادئة جداول قاعدة البيانات');
@define('INSTALL_DBPREFIX_DESC', 'بادئة الجداول مثال - serendipity_');

/* PATHS */
@define('INSTALL_CAT_PATHS', 'مسارات');
@define('INSTALL_CAT_PATHS_DESC', 'هذه مسارات متعددة لمجلدات و ملفات أساسية في عمل المجلة - لا تنسى أن تضع الشرطة (/) المقلوبة بعد مسمى المجلدات');
@define('INSTALL_FULLPATH', 'المسار الكامل');
@define('INSTALL_FULLPATH_DESC', 'المسار الكامل والدقيق الى مجلد الاعدادات (الانستوليش) لمدونتك');
@define('INSTALL_UPLOADPATH', 'مسار رفع الملفات');
@define('INSTALL_UPLOADPATH_DESC', 'جميع الملفات والصور المرفوعة سوف تكون هنا, \'Full path\' - typically \'uploads/\'');
@define('INSTALL_RELPATH', 'مسارات ذات صلة');
@define('INSTALL_RELPATH_DESC', 'مهم : المسار الى مدونتك بالمتصفح أي عنوان مدونتك, typically \'/serendipity/\'');
@define('INSTALL_RELTEMPLPATH', 'مسارات ذات صلة بالقوالب');
@define('INSTALL_RELTEMPLPATH_DESC', 'The path to the folder containing your templates - Relative to the \'relative path\'');
@define('INSTALL_RELUPLOADPATH', 'مسار رفع المفات');
@define('INSTALL_RELUPLOADPATH_DESC', 'المسار الذي يؤدي إلى رفع الملفات من متصفحك \'relative path\'');
@define('INSTALL_URL', 'رابط اللوقو');
@define('INSTALL_URL_DESC', 'الرابط الاساسي لتثبيت و تركيب المجلة. الانستوليشن');
@define('INSTALL_INDEXFILE', 'Index file');
@define('INSTALL_INDEXFILE_DESC', 'أسم ملف الاندكس للمدونة');

/* GENERAL SETTINGS */
@define('INSTALL_CAT_SETTINGS', 'إعدادات عامة');
@define('INSTALL_CAT_SETTINGS_DESC', 'تفضيلات لإداء المجلة');
@define('INSTALL_USERNAME', 'اسم المستخدم للمشرف');
@define('INSTALL_USERNAME_DESC', 'اسم المستخدم للمشرف');
@define('INSTALL_PASSWORD', 'كلمة مرور المشرف');
@define('INSTALL_PASSWORD_DESC', 'كلمة المرور للمشرف');
@define('INSTALL_EMAIL', 'بريد المشرف');
@define('INSTALL_EMAIL_DESC', 'بريد المشرف العام للمدونة');
@define('INSTALL_SENDMAIL', 'أرسال بريد إلى المشرف العام؟');
@define('INSTALL_SENDMAIL_DESC', 'هل تريد أن يصلك بريد عندما يكتب تعليق على أحد مواضيعك؟ الأفضل نعم. لمتابعة مدونتك');
@define('INSTALL_SUBSCRIBE', 'السماح للزوار بالمشاركة في المواضيع؟');
@define('INSTALL_SUBSCRIBE_DESC', 'السماح للزوار بالمشاركة في المواضيع. وبذلك يصل لك بريد عند كل تعليق أو مشاركة على مواضيعك');
@define('INSTALL_BLOGNAME', 'أسم المجلة');
@define('INSTALL_BLOGNAME_DESC', 'عنوان المجلة');
@define('INSTALL_BLOGDESC', 'وصف المجلة');
@define('INSTALL_BLOGDESC_DESC', 'هنا ضع وصفاً مختصراً عن مهمة وأفكار مدونتك');
@define('INSTALL_LANG', 'اللغة');
@define('INSTALL_LANG_DESC', 'أختر لغة مدونتك');

/* APPEARANCE AND OPTIONS خيارات و خصائص */
@define('INSTALL_CAT_DISPLAY', 'خيارات و خصائص');
@define('INSTALL_CAT_DISPLAY_DESC', 'تفاصيل كيف تود ان يكون مظهر المجلة');
@define('INSTALL_WYSIWYG', 'صندوق التحرير المتطور');
@define('INSTALL_WYSIWYG_DESC', 'صندوق التحرير المتطور يسهل عليك عملية تنسيق الكتابة؟ ولكنه لا يعمل على جميع أنواع المتصفحات. يعمل على الاكسبلورر والافانت والفيرفوكس');
@define('INSTALL_XHTML11', 'Force XHTML 1.1 compliance');
@define('INSTALL_XHTML11_DESC', 'Do you want to force XHTML 1.1 compliance (may cause problems for back-/frontend on older 4th generation browsers)');
@define('INSTALL_POPUP', 'تمكين النوافذ المنبثقة أو التلقائية؟');
@define('INSTALL_POPUP_DESC', 'هل تود استخدام النوافذ المنبثقة في التعليقات، روابط تعقب التعليقات وغيرها؟');
@define('INSTALL_EMBED', 'هل تريد المجلة تكون جزء واحد؟');
@define('INSTALL_EMBED_DESC', 'إذا أردت أن تجعل مدونتك مجموعة على هيئة صفحات عادية أختر الخيار (صحيح) كي يتجاهل الهدر و يتم طباعة محتوى الموضوع فقط. كذلك يمكن لك ذلك باستخدام خيارات صفحة الاندكس  وأستخدم الغلاف في أي مكان تضع فيه يكون هدر المجلة عادي. اطلع على ملف أقرئني لمعرفة معلومات تفصيلية عن ذلك');
@define('INSTALL_TOP_AS_LINKS', 'Show Top Exits/Referrers as links?');
@define('INSTALL_TOP_AS_LINKS_DESC', '"no": Exits and Referrers are shown as plain text to prevent google spam. "yes": Exits and Referrers are shown as hyperlinks. "default": Use setting from global configuration (recommended).');
@define('INSTALL_BLOCKREF', 'Blocked Referers');
@define('INSTALL_BLOCKREF_DESC', 'Are there any special hosts you want not to show up in the referers list? Separate the list of hostnames with \';\' and note that the host is blocked by substring matches!');
@define('INSTALL_REWRITE', 'URL Rewriting');
@define('INSTALL_REWRITE_DESC', 'Select which rules you wish to use when generating URLs. Enabling rewrite rules will make pretty URLs for your blog and make it better indexable for spiders like google. The webserver needs to support either mod_rewrite or "AllowOverride All" for your serendipity dir. The default setting is auto-detected');

/* IMAGECONVERSION SETTINGS */
@define('INSTALL_CAT_IMAGECONV', 'أعدادات تحويل الصور');
@define('INSTALL_CAT_IMAGECONV_DESC', 'ضع معلومات عامة عن كيفية تعامل المجلة للصور');
@define('INSTALL_IMAGEMAGICK', 'أستخدم ايمج ماجيك');
@define('INSTALL_IMAGEMAGICK_DESC', 'هل انت مركب برنامج ايمج مجك في سيرفرك و تود أستخدامة في تصغير وتعديل الصور؟');
@define('INSTALL_IMAGEMAGICKPATH', 'مسار تحويل المعلومات');
@define('INSTALL_IMAGEMAGICKPATH_DESC', 'المسار و الأسم الكامل إلى برنامج التحويل اميج ماجك على سيرفرك');
@define('INSTALL_THUMBSUFFIX', 'لاحقة الصور المصغرة');
@define('INSTALL_THUMBSUFFIX_DESC', 'سوف يعطى للصور المصغرة االأسم والصيغة التالية: original.[suffix].ext');
@define('INSTALL_THUMBWIDTH', 'قياسات الصورة المصغرة');
@define('INSTALL_THUMBWIDTH_DESC', 'العرض الثابت لصور المصغرة المنشئة أتماتيكياً');

/* Personal details */
@define('USERCONF_CAT_PERSONAL', 'تفصيل اعدادتك الشخصية');
@define('USERCONF_CAT_PERSONAL_DESC', 'تغيير تفصيل الاعدادت الشخصية');
@define('USERCONF_USERNAME', 'أسم المستخدم');
@define('USERCONF_USERNAME_DESC', 'الاسم الذي تستخدمة بالتسجيل في مدونتك');
@define('USERCONF_PASSWORD', 'كلمة المرور الخاصة بك');
@define('USERCONF_PASSWORD_DESC', 'كلمة المرور التي تستخدمها بالتسجيل الدخول في مدونتك');
@define('USERCONF_EMAIL', 'بريدك الالكتروني');
@define('USERCONF_EMAIL_DESC', 'ضع بريدك الشخصي كي يتم المراسله من خلالة');
@define('USERCONF_SENDCOMMENTS', 'أرسال تبليغ في حال تم كتابة تعليق؟ ');
@define('USERCONF_SENDCOMMENTS_DESC', 'هل تريد أن يصلك بريد عندما يكتب تعليق على أحد مواضيعك؟ الأفضل نعم. لمتابعة مدونتك');
@define('USERCONF_SENDTRACKBACKS', 'أرسال تبليغ برابط التعقيب؟');
@define('USERCONF_SENDTRACKBACKS_DESC', 'هل تود أستقبال بريد عندما يتم التعقيب على مواضيعك؟ الأفضل نعم');
@define('USERCONF_ALLOWPUBLISH', 'حقوق: نشر الموضوع؟');
@define('USERCONF_ALLOWPUBLISH_DESC', 'هل يحق للمستخدم نشر مواضيع؟');
@define('SUCCESS', 'نجاح');
@define('POWERED_BY_SHOW_TEXT', 'أعرض المجلة على هيئة نص تكست');
@define('POWERED_BY_SHOW_TEXT_DESC', 'سوف يتم عرض المجلة على هيئة نص تكست');
@define('POWERED_BY_SHOW_IMAGE', 'أعرض المجلة مع الشعار الخاص بها');
@define('POWERED_BY_SHOW_IMAGE_DESC', 'أعرض شهار المجلة');
@define('PLUGIN_ITEM_DISPLAY', 'اين يمكن عرضها؟');
@define('PLUGIN_ITEM_DISPLAY_EXTENDED', 'فقط المواضيع المتممدة');
@define('PLUGIN_ITEM_DISPLAY_OVERVIEW', 'عرض الصفحة فقط');
@define('PLUGIN_ITEM_DISPLAY_BOTH', 'جميع المواد');
@define('RSS_IMPORT_CATEGORY', 'أستخدم هذا التصنيف لإستيراد المقالات الغير متطابقة');

@define('COMMENTS_WILL_BE_MODERATED', 'سوف يطلع المشرف على التعليقات المدرجة قبل نشرها');
@define('YOU_HAVE_THESE_OPTIONS', 'متوفر لديك هذا الخيارات:');
@define('THIS_COMMENT_NEEDS_REVIEW', 'تحذير: هذا التعقيب يحتاج الى الموافقة قبل عرضه! ! !');
@define('DELETE_COMMENT', 'أحذف التعقيب');
@define('APPROVE_COMMENT', 'أوافق على التعقيب');
@define('REQUIRES_REVIEW', 'يحتاج إلى مراجعه');
@define('COMMENT_APPROVED', 'التعقيب #%s تم الموافقة عليه بنجاح');
@define('COMMENT_DELETED', 'التعقيب  #%s تم حذفه بنجاح');
@define('COMMENTS_MODERATE', 'التعاقيب و روابط التعقيب في هذا الموضوع تحتاج إلى رأي المشرف! ! !');
@define('THIS_TRACKBACK_NEEDS_REVIEW', 'تحذير: رابط التعقيب هذا يحتاج إلى الموافقة قبل عرضه! ! !');
@define('DELETE_TRACKBACK', 'أخذف رابط التعقيب');
@define('APPROVE_TRACKBACK', 'موافقه على رابط التعقيب');
@define('TRACKBACK_APPROVED', 'تعقب الرابط #%s تم الموافقة عليه بنجاح');
@define('TRACKBACK_DELETED', 'تعقب الرابط #%s تم حذفه بنجاح');
@define('VIEW', 'View');
@define('COMMENT_ALREADY_APPROVED', 'التعليق #%s موافق عليه فقط للمصرح لهم');
@define('COMMENT_EDITED', 'تم حذف هذا التعليق');
@define('HIDE', 'إخفاء');
@define('VIEW_EXTENDED_ENTRY', 'تتمة موضوع "%s"');
@define('TRACKBACK_SPECIFIC_ON_CLICK', 'This link is not meant to be clicked. It contains the trackback URI for this entry. You can use this URI to send ping- & trackbacks from your own blog to this entry. To copy the link, right click and select "Copy Shortcut" in Internet Explorer or "Copy Link Location" in Mozilla.');
@define('PLUGIN_SUPERUSER_HTTPS', 'Use https for login');
@define('PLUGIN_SUPERUSER_HTTPS_DESC', 'Lets the login-link point to a https-location. Your webserver needs to support this!');
@define('INSTALL_SHOW_EXTERNAL_LINKS', 'تمكين الروابط الخارجية؟');
@define('INSTALL_SHOW_EXTERNAL_LINKS_DESC', '"لا": تعني عدم تمكين روابط الشعبية الخارجية  في المجلة مثال (أفضل المواضيع - أفضل المراجعات – تعليقات  العضو) وهذا يمنع السخام الناتج من محرك قوقل و يفضل هذا الاختيار. "نعم" الروابط الشعبية الخارجية سوف تعرض على أنه لم يتم زيارتها. ويمكن أن تتجاوز ذلك باستخدام أعدادات قالب العمود الجانبي !!');
@define('PAGE_BROWSE_COMMENTS', 'الصفحة رقم %s من %s, مجموع %s تعليقات');
@define('FILTERS', 'تدقيق');
@define('FIND_ENTRIES', 'البحث عن مواضيع');
@define('FIND_COMMENTS', 'البحث عن تعليقات');
@define('FIND_MEDIA', 'البحث عن وسائط متعددة');
@define('FILTER_DIRECTORY', 'مجلد');
@define('SORT_BY', 'فرز حسب');
@define('TRACKBACK_COULD_NOT_CONNECT', 'No Trackback sent: Could not open connection to %s on port %d');
@define('MEDIA', 'ملفات الميديا');
@define('MEDIA_LIBRARY', 'مكتبة الوسائط المتعددة');
@define('ADD_MEDIA', 'اضافة وسائط متعددة');
@define('ENTER_MEDIA_URL', 'أدخل رابط الملف المطلوب:');
@define('ENTER_MEDIA_UPLOAD', 'اختر الملف الذي تريد رفعة:');
@define('SAVE_FILE_AS', 'حفظ الملف بأسم:');
@define('STORE_IN_DIRECTORY', 'تخزينه في داخل هذا المجلد: ');
@define('ADD_MEDIA_BLAHBLAH', '<b>أضافة ملف الى الميديا تحت مسئوليتك:</b><p> هنا يمكن لك رفع ملفات الميديا ، أو اخبرنا عنها كي يتم جلبها من أي مكان في الانترنت! أن لم يكن لديك الصورة المناسبة <a href="http://images.google.com" target="_blank"> ابحث عن الصورة المطلوبة في قوقل للصور </a> التي تناسب فكرة موضوعك ، والنتيجة أحيانا تكون مضحكة أو عادية ، ولكن عليك مراعاة حقوق النشر ، لذلك يتوجب عليك السؤال عنها قبل أن تأخذها من مصدرها<p><b> أختر الطريقة التي تناسبك:</b><br/>');
@define('MEDIA_RENAME', 'أعادة تسمية الملف');
@define('IMAGE_RESIZE', 'تغيير قياسات هذه الصورة');
@define('MEDIA_DELETE', 'حذف الملف');
@define('FILES_PER_PAGE', 'الملفات في كل صفحة');
@define('CLICK_FILE_TO_INSERT', 'اضغط على الملف الذي تريد ادخالة:');
@define('SELECT_FILE', 'اختر الملف كي يتم ادخالة');
@define('MEDIA_FULLSIZE', 'حجم الملف');
@define('CALENDAR_BOW_DESC', 'يجب أخذ الاعتبار في اليوم الذي يبدأ به الأسبوع - عادة الاثني');
@define('SUPERUSER', 'ادارة المجلة');
@define('ALLOWS_YOU_BLAHBLAH', 'وضع رابط في القائمة الجانبية يوصل إلى لوحة تحكم المجلة');
@define('CALENDAR', 'التقويم');
@define('SUPERUSER_OPEN_ADMIN', 'إدارة مفتوحة');
@define('SUPERUSER_OPEN_LOGIN', 'افتح شاشة التسجيل');
@define('INVERT_SELECTIONS', 'ترتي عكسي');
@define('COMMENTS_DELETE_CONFIRM', 'هل انت متأكد من حذف هذه التعليقات؟');
@define('COMMENT_DELETE_CONFIRM', 'هل انت متأكد من حذف التعليق #%d, للكاتب %s ?');
@define('DELETE_SELECTED_COMMENTS', 'احذف التعليقات المختارة');
@define('VIEW_COMMENT', 'اعرض التعليق');
@define('VIEW_ENTRY', 'أعرض الموضوع');
@define('DELETE_FILE_FAIL' , 'لا يمكن حذف الملف <b>%s</b>');
@define('DELETE_THUMBNAIL', 'حذف الصورة والصورة المصغره بعنوانها <b>%s</b>');
@define('DELETE_FILE', 'حذف عنوان الملف <b>%s</b>');
@define('ABOUT_TO_DELETE_FILE', 'انت على وشك أن تحذف <b>%s</b><br />إذا كنت تستخدم هذا الملف في بعض مواضيعك ، سوف لن تظهر الصور أو الرابط لن يكون شغال<br /> هل أنت متأكد من أنك تريد الحذف؟<br /><br />');
@define('TRACKBACK_SENDING', 'ارسال تقصي للرابط %s...');
@define('TRACKBACK_SENT', 'نجح في تعقب الموضوع');
@define('TRACKBACK_FAILED', 'فشل في تعقب %s');
@define('TRACKBACK_NOT_FOUND', 'لم يتم ايجاد أي تعقب للرابط');
@define('TRACKBACK_URI_MISMATCH', 'The auto-discovered trackback URI does not match our target URI.');
@define('TRACKBACK_CHECKING', 'فحص <u>%s</u> ان كان موجود أي رابط تعقب...');
@define('TRACKBACK_NO_DATA', 'لا يوجد أي معلومات في هذا الهدف');
@define('TRACKBACK_SIZE', 'Target URI exceeded maximum filesize of %s bytes.');
@define('COMMENTS_VIEWMODE_THREADED', 'متواصل');
@define('COMMENTS_VIEWMODE_LINEAR', 'تخطيطي');
@define('DISPLAY_COMMENTS_AS', 'أعرض التعليقات على شكل');
@define('COMMENTS_FILTER_SHOW', 'عرض');
@define('COMMENTS_FILTER_ALL', 'الكل');
@define('COMMENTS_FILTER_APPROVED_ONLY', 'فقط ما تمت الموافقة عليه');
@define('COMMENTS_FILTER_NEED_APPROVAL', 'الموافقه على المنع أو الحجب');
@define('RSS_IMPORT_BODYONLY', 'Put all imported text in the "body" section and do not split up into "extended entry" section.');
@define('SYNDICATION_PLUGIN_FULLFEED', 'أعرض المقالة كاملة متممدة داخل معطيات RSS');
@define('WEEK', 'اسبوع');
@define('WEEKS', 'أسابيع');
@define('MONTHS', 'أشهر');
@define('DAYS', 'أيام');
@define('ARCHIVE_FREQUENCY', 'بنود تتكرر في التقويم');
@define('ARCHIVE_FREQUENCY_DESC', 'فاصل التوقيت الزمني بين كل موضوع والأخر في قائمة');
@define('ARCHIVE_COUNT', 'عدد المواضيع في كل قائمة');
@define('ARCHIVE_COUNT_DESC', 'الرقم الكلي لعدد الاشهر - الاسابيع - الأيام التي سيتم العرض بها');
@define('BELOW_IS_A_LIST_OF_INSTALLED_PLUGINS', 'في الاسفل يظهر لك قائمة بملفات الحث (بلوق ان) التي تم تركيبها');
@define('SIDEBAR_PLUGIN', 'البلوقات الجانبية للمجلة');
@define('EVENT_PLUGIN', 'بلوقات لأحداث مختلفه');
@define('CLICK_HERE_TO_INSTALL_PLUGIN', 'أضغط هنا لتثبيت جديد %s');
@define('VERSION', 'أصدار');
@define('INSTALL', 'تثبيت أو تركيب');
@define('ALREADY_INSTALLED', 'تم تثبيت هذا الإجراء مسبقاً');
@define('SELECT_A_PLUGIN_TO_ADD', 'أختر ملف الحث - بلوق ان -الذي تريد تركيبة');
@define('INSTALL_OFFSET', 'حفظ وقت العمل');
@define('STICKY_POSTINGS', 'مشاركة مثبته');
@define('INSTALL_FETCHLIMIT', 'عدد المواضيع التي تعرض في الصفحة الرئيسية');
@define('INSTALL_FETCHLIMIT_DESC', 'عدد التعليقات التي يتم عرضها تابعة للموضوع في كل صفحة');
@define('IMPORT_ENTRIES', 'أستيراد المعلومات');
@define('EXPORT_ENTRIES', 'تصدير المواضيع');
@define('IMPORT_WELCOME', 'مرحبا بك في ادوات استيراد للمدونة');
@define('IMPORT_WHAT_CAN', 'هنا يمكن لك أستيراد مواضيع من مدونات أخرى مثل نيكولاس و وررد برس و إيفلوشن! ! !');
@define('IMPORT_SELECT', 'الرجاء أختيار نوع السكربت الذي تريد أن تستورد منه معلومات!!!');
@define('IMPORT_PLEASE_ENTER', 'الرجاء أدخل المعلومات المطلوبه في الأسفل');
@define('IMPORT_NOW', 'أستيراد الآن!');
@define('IMPORT_STARTING', 'بدأ أجراء الاستيراد ...');
@define('IMPORT_FAILED', 'فشل في الاستيراد');
@define('IMPORT_DONE', 'انتهى الاستيراد بنجاح');
@define('IMPORT_WEBLOG_APP', 'تطبيقات المجلة');
@define('IMPORT_NOTES', 'ملاحظة:');
@define('EXPORT_FEED', 'Export full RSS feed');
@define('STATUS', 'الحالة بعد الاستيراد');
@define('IMPORT_GENERIC_RSS', 'Generic RSS import');
@define('ACTIVATE_AUTODISCOVERY', 'أرسل رابط تعقب لما هو موجود في هذا الموضوع');
@define('WELCOME_TO_ADMIN', 'مرحبا بك في لوحة تحكم المشرف العام للمدونة');
@define('PLEASE_ENTER_CREDENTIALS', 'الرجاء إدخال المعلومات الخاصة بك.');
@define('ADMIN_FOOTER_POWERED_BY', 'يستخدم مدونة سيرندبيتي الأصدار %s و PHP %s');
@define('INSTALL_USEGZIP', 'أستخدم خاصية ضغط الصفحات - gzip ');
@define('INSTALL_USEGZIP_DESC', 'لكي تتمكن من تسريع تصفح المجلة. بالإمكان ضغط الصفحات التي ترسل إلى الزوار. على أن يكون المتصفح لديه يدعم هذه الخاصية. يفضل عمل ذلك! ! !');
@define('INSTALL_SHOWFUTURE', 'أعرض المواضيع المستقبلية');
@define('INSTALL_SHOWFUTURE_DESC', 'ان تم تمكين هذا فإنه سوف يعرض مستقبلا جميع مواضيع المجلة. الخيار الافتراضي هو إخفاء المواضيع و تعرض فقط عند تاريخ النشر');
@define('INSTALL_DBPERSISTENT', 'أستخدام الاتباط الحالي');
@define('INSTALL_DBPERSISTENT_DESC', 'تمكن استخدام الاتصال الدائم لقاعدة البيانات. يمكنك قراءة المزيد هنا <a href="http://php.net/manual/features.persistent-connections.php" target="_blank"> هنــا </a> ينصح بهذا الاجراء');
@define('NO_IMAGES_FOUND', 'لم يتم العثور على الصورة');
@define('PERSONAL_SETTINGS', 'الاعدادات الشخصية');
@define('REFERER', 'يشير إلى');
@define('NOT_FOUND', 'لم يتم إيجادة');
@define('WRITABLE', 'قابل للكتابة');
@define('NOT_WRITABLE', 'غير قابل للكتابة');
@define('PROBLEM_DIAGNOSTIC', 'بسبب مشكل تفحص. لا يمكن لك الإستمرار في عمليت التثبيت حتى تتمكن من تعديل هذا الخطأ');
@define('SELECT_INSTALLATION_TYPE', 'أختر أي طريقة تثبيت تفضل');
@define('WELCOME_TO_INSTALLATION', 'مرحبا بك في صفحة تثبيت المجلة سيرندبيتي');
@define('FIRST_WE_TAKE_A_LOOK', 'أولا سوف يتم النظر في الاعدادات الحالية. ثم تفحص أي مشاكل يمكن أن تحدث');
@define('ERRORS_ARE_DISPLAYED_IN', 'خطأ معروض في  %s. يوصى في %s و نجاح %s');
@define('RED', 'red');
@define('YELLOW', 'أصفر');
@define('GREEN', 'أخضر');
@define('PRE_INSTALLATION_REPORT', 'Serendipity v%s pre-installation report');
@define('RECOMMENDED', 'ينصح به');
@define('ACTUAL', 'فعلي');
@define('PHPINI_CONFIGURATION', 'php.ini تهيئة اعدادات');
@define('PHP_INSTALLATION', 'PHP تثبيت');
@define('THEY_DO', 'يمكن لهم');
@define('THEY_DONT', 'لا يمكن لهم');
@define('SIMPLE_INSTALLATION', 'التثبيت البسيط');
@define('EXPERT_INSTALLATION', 'التثبيت المتقدم');
@define('COMPLETE_INSTALLATION', 'تم الانتهاء من التثبيت');
@define('WONT_INSTALL_DB_AGAIN', 'لن يتم تثبيت قاعدة البيانات من جديد');
@define('CHECK_DATABASE_EXISTS', 'تفحص إن كانت قاعدة البيانات و الجداول موجودة');
@define('CREATING_PRIMARY_AUTHOR', 'إنشاء محرر رأيسي \'%s\'');
@define('SETTING_DEFAULT_TEMPLATE', 'إعدادات المجلة الإفتراضية');
@define('INSTALLING_DEFAULT_PLUGINS', 'تثبيت البلوق ان الافتراضي');
@define('SERENDIPITY_INSTALLED', 'تم تركيب مدونة سيندربيتي بنجاح');
@define('VISIT_BLOG_HERE', 'يمكنك زيارة مدونتك الجديدة من هنا');
@define('THANK_YOU_FOR_CHOOSING', 'شكرا لأختيارك مدونة سيندربيتي');
@define('ERROR_DETECTED_IN_INSTALL', 'تم أكتشاف خطأ خلال مرحلة التقبيت');
@define('OPERATING_SYSTEM', 'نظام التشغيل');
@define('WEBSERVER_SAPI', 'Webserver SAPI');
@define('TEMPLATE_SET', '\'%s\' تم أختيارة ليكون القالب النشط');
@define('SEARCH_ERROR', 'وظيفة البحث لم تعمل كما ينبغي لها. هذه ملاحظة للمشرف العام للمدونة.: هذه يمكن أن تحدث بسبب فقدن أحد معرفات جداول قاعدة البيانات. في نظام MySQL يحتاج المستخدم إلى ميزات لهذه الإجراءات:  <pre> إنشاء y_idx مصفوفة (عنوان ، جسم للصفحة ، متمدد) </pre> هذا الخطأ من قاعدة البيانات كان <pre>%s</pre>');
@define('EDIT_THIS_CAT', 'تحرير "%s"');
@define('CATEGORY_REMAINING', 'أحذف هذا التصنيف و قم بنقل جميع محتوياته إلى التصنيف التالي');
@define('CATEGORY_INDEX', 'هذه قائمة بالأقسام الموجودة لمواضيعك:');
@define('NO_CATEGORIES', 'لم يتم ادراج أقسام');
@define('RESET_DATE', 'Reset date');
@define('RESET_DATE_DESC', 'أضغط هنا كي تحدث التوقيت إلى توقيت ىلآن');
@define('PROBLEM_PERMISSIONS_HOWTO', 'Permissions can be set by running shell command: `<em>%s</em>` on the failed directory, or by setting this using an FTP program');
@define('WARNING_TEMPLATE_DEPRECATED', 'تحذير: القالب الحالي ناقص بعض المعلومات ! ! نصيحة بأن تقوم بتحديث هذا القالب إن أمكن');
@define('ENTRY_PUBLISHED_FUTURE', 'لم يتم نشر هذا الموضوع إلى الآن');
@define('ENTRIES_BY', 'المواضيع بواسطة %s');
@define('PREVIOUS', 'السابق');
@define('NEXT', 'التالي');
@define('APPROVE', 'موافق');
@define('DO_MARKUP_DESCRIPTION', 'يمكن تحويل الاحرف القياسية إلى علامات أو إبتسامات مثال (الابتسامات, الاختصارات بواسطة *, /, _, ...) عدم التمكين سوف يحتفظ بجميع أكواد HTML على انها نصوص فقط.');
@define('CATEGORY_ALREADY_EXIST', 'التصنيف المسمى  "%s" مدخل مسبقاً');
@define('ERROR_FILE_FORBIDDEN', 'لا يحق لك أن ترفع ملفات تضم محتويات نشطة');
@define('ADMIN', 'ادارة المجلة');
@define('ADMIN_FRONTPAGE', 'صفحة البداية');
@define('QUOTE', 'أقتباس');
@define('IFRAME_SAVE', 'يتم الآن حفظ مقالاتك و إنشاء روابط تعقب الموضوع و إمكانية عمل إعلانات XML-RPC – من الممكن أن يستغرق بعض الوقت . . .  شكرا لانتظارك');
@define('IFRAME_SAVE_DRAFT', 'تم الإنتهاء من حفظ مسودة هذه المقالة');
@define('IFRAME_PREVIEW', 'يتم الآن انشاء عرض المشاهدة لمشاركة ...');
@define('IFRAME_WARNING', 'متصفحك لا يدعم صفحات الاطارات iframes الرجا فتح الملف _config.inc.php وأضبط المتغير $serendipity[\'use_iframe\'] variable to FALSE');
@define('NONE', 'لا يوجد');
@define('USERCONF_CAT_DEFAULT_NEW_ENTRY', 'الاعدادات الافتراضيه للمواضيع الجديدة');
@define('UPGRADE', 'تحديث');
@define('UPGRADE_TO_VERSION', 'تحديث للأصدار %s');
@define('DELETE_DIRECTORY', 'حذف المجلد');
@define('DELETE_DIRECTORY_DESC', 'أنت على وشك حذف مجلد  بمحتوياته من ملفات ميديا وصور وغيرها! ! ! من الممكن أن بعض هذه الملفات مستخدمة في احد مواضيعك. تأكد ! ! !');
@define('FORCE_DELETE', 'أحذف جميع محتويات هذا المجلد بما فيها الملفات التي ليست للمدونة! ! !');
@define('CREATE_DIRECTORY', 'أنشاء مجلد');
@define('CREATE_NEW_DIRECTORY', 'انشاء مجلد جديد');
@define('CREATE_DIRECTORY_DESC', 'هنا يمكن أنشاء مجلد لوضوع الملفات المختلفه (ميديا) فيه. أختر أسم للمجلد الجديد وكذلك أختر المجلد الاب له لوضوعه فيه');
@define('BASE_DIRECTORY', 'مجلد قاعدة');
@define('USERLEVEL_EDITOR_DESC', 'محرر عادي ');
@define('USERLEVEL_CHIEF_DESC', 'رئيس المحررين');
@define('USERLEVEL_ADMIN_DESC', 'المشرف العام');
@define('USERCONF_USERLEVEL', 'مستوى الوصول');
@define('USERCONF_USERLEVEL_DESC', 'هنا توضيح لمستوى وصلاحيات دخول المستخدم إلى المجلة');
@define('USER_SELF_INFO', 'تم التسجيل بـ %s (%s)');
@define('ADMIN_ENTRIES', 'المواضيع');
@define('RECHECK_INSTALLATION', 'إعادة تفحص تثبيت المجلة');
@define('IMAGICK_EXEC_ERROR', 'غير قادر على تنفيذ "%s", خطأ: %s, مرجع الخطأ: %d');
@define('INSTALL_OFFSET_DESC', 'أدخل فارق التوقيت بين السيرفر (توقيت السيرفر  %clock%) و توقيت المنطقة التي تريدها');
@define('UNMET_REQUIREMENTS', 'متطلبات فاشله: %s');
@define('CHARSET', 'Charset');
@define('AUTOLANG', 'أستخدم اللغة الافتراضية لمتصفح الزائر/ الزوار');
@define('AUTOLANG_DESC', 'إن تم تمكين هذا الخيار سوف تتحول اللغة بناء على اللغة المستخدمة من قبل متصفح الزائر / الزوار');
@define('INSTALL_AUTODETECT_URL', 'التعرف التلقائي على نطاق (Domain) الموقع');
@define('INSTALL_AUTODETECT_URL_DESC', 'أن أختر الخيار صحيح. سوف تتمكن المجلة من معرفة الرابط الذي يستخدمه الزوار على أنه الرابط الأساسي. باختيارك هذا الخيار يجعلك قادر على استخدام أكثر من أسم نطاق (دومين) للوصول إلى مدونتك. وسوف يستخدم أسم النطاق هذا لجميع الروابط التابعة للمدونة');
@define('CONVERT_HTMLENTITIES', 'جرب تحويل المواضيع إلى هتمل؟');
@define('EMPTY_SETTING', 'لم تقم بأعطاء معلومات دقيقة عن "%s"!');
@define('USERCONF_REALNAME', 'الأسم الحقيقي'); // Translate
@define('USERCONF_REALNAME_DESC', 'الأسم الكامل للمحرر أو الناشر. وهذا سوف يظهر لقراء الموضوع'); // Translate
@define('HOTLINK_DONE', 'رابط فعال<br />تم'); // Translate
@define('ENTER_MEDIA_URL_METHOD', 'طريقة جلب الصورة'); // Translate
@define('ADD_MEDIA_BLAHBLAH_NOTE', 'ملاحظة: في حال جلب صورة من رابط معين تأكد أن الموقع الذي سوف تحمل الصورة منه يسمح بعرض الصور في مواقع أخرى. أو تأكد أن هذا الرابط من موقعك. عرض الصور بواسطة رابطها يعنيك عن تحميل الصورة في مدونتك أو موقعك (مثال استخدام مراكز تحميل الصور)'); // Translate
@define('MEDIA_HOTLINKED', 'من رابط'); // Translate
@define('FETCH_METHOD_IMAGE', 'رفع الصورة إلى موقعك'); // Translate
@define('FETCH_METHOD_HOTLINK', 'رابط صورة إلى موقع'); // Translate
@define('DELETE_HOTLINK_FILE', 'تم حذف الرابط النشط والملف <b>%s</b>'); // Translate
@define('SYNDICATION_PLUGIN_SHOW_MAIL', 'أعرض البريد الالكتروني؟');
@define('IMAGE_MORE_INPUT', 'أضف صور أكثر');
@define('BACKEND_TITLE', 'معلومات إضافية عن وظيفة هذا الاجراء'); // Translate
@define('BACKEND_TITLE_FOR_NUGGET', 'يمكن لك هنا وضع الوصف المناسب للأجراء الذي سوف تقوم به ولن يتم عرضه على الزائر ، ان الوصف الذي تقدمه هنا مفيد جداً لو كان لديك أكثر من HTML Nugget  في مدونتك و لم تعطها عناوين وهو يساعد بتعريفك كل إجراء عن الاخر'); // Translate
@define('CATEGORIES_ALLOW_SELECT', 'السماح للزوار بعرض أقسام متعددة مرة واحدة؟'); // Translate
@define('CATEGORIES_ALLOW_SELECT_DESC', 'في حال تشغيل هذا الخيار فإن صندوق إختيار سوف يتم عرضة بجانب مسمى كل قسم من أقسام المجلة ، وبذلك الزائر يمكن له التعليم على الاقسام التي يريد الاطلاع عليها فقط'); // Translate
@define('PAGE_BROWSE_PLUGINS', 'الصفحة رقم %s من %s, مجموع %s مواضيع.');
@define('INSTALL_CAT_PERMALINKS', 'الروابط الدائمة');
@define('INSTALL_CAT_PERMALINKS_DESC', 'هنا توضيح لروابط مختلفة وهي روابط دائمة في عمل المجلة ، يفترض عليك أن تستخدم الخيار الافتراضي في هذه المجموعة. وإن أردت تغيير شيء فيمكن لك المحاولة باستخدام التعارف والقيم    مثل %id% ما أمكن الأمر من ذلك كي لا يكون هناك اختلاف في وصول المعلومات إلى قاعدة البيانات');
@define('INSTALL_PERMALINK', 'بنية إدخال الرابط الاساسي');
@define('INSTALL_PERMALINK_DESC', 'Here you can define the relative URL structure beginning from your base URL to where entries may become available. You can use the variables %id%, %title%, %day%, %month%, %year% and any other characters.');
@define('INSTALL_PERMALINK_AUTHOR', 'الرابط الدائم للوصول إلى كاتب الموضوع');
@define('INSTALL_PERMALINK_AUTHOR_DESC', 'Here you can define the relative URL structure beginning from your base URL to where entries from certain authors may become available. You can use the variables %id%, %realname%, %username%, %email% and any other characters.');
@define('INSTALL_PERMALINK_CATEGORY', 'Permalink Category URL structure');
@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Here you can define the relative URL structure beginning from your base URL to where entries from certain categories may become available. You can use the variables %id%, %name%, %description% and any other characters.');
@define('INSTALL_PERMALINK_FEEDCATEGORY', 'Permalink RSS-Feed Category URL structure');
@define('INSTALL_PERMALINK_FEEDCATEGORY_DESC', 'Here you can define the relative URL structure beginning from your base URL to where RSS-feeds from certain categories may become available. You can use the variables %id%, %name%, %description% and any other characters.');
@define('INSTALL_PERMALINK_FEEDAUTHOR', 'Permalink RSS-Feed Author URL structure');
@define('INSTALL_PERMALINK_FEEDAUTHOR_DESC', 'Here you can define the relative URL structure beginning from your base URL to where RSS-feeds from specific users may be viewed. You can use the variables %id%, %realname%, %username%, %email% and any other characters.');
@define('INSTALL_PERMALINK_ARCHIVESPATH', 'مسار الأرشيفات');
@define('INSTALL_PERMALINK_ARCHIVEPATH', 'مسار الأرشيف');
@define('INSTALL_PERMALINK_CATEGORIESPATH', 'مسار الأقسام');
@define('INSTALL_PERMALINK_AUTHORSPATH', 'مسار الكتاب أو المحررين');
@define('INSTALL_PERMALINK_UNSUBSCRIBEPATH', 'مسار التعليقات الغير مشاركة');
@define('INSTALL_PERMALINK_DELETEPATH', 'مسار التعليقات المحذوفة');
@define('INSTALL_PERMALINK_APPROVEPATH', 'مسار التعليقات التي تمت الموافقة عليها');
@define('INSTALL_PERMALINK_FEEDSPATH', 'مسار RSS');
@define('INSTALL_PERMALINK_PLUGINPATH', 'مسار بلوق ان معين');
@define('INSTALL_PERMALINK_ADMINPATH', 'مسار لوحة التحكم');
@define('INSTALL_PERMALINK_SEARCHPATH', 'مسار البحث');
@define('INSTALL_CAL', 'نوع التقويم');
@define('INSTALL_CAL_DESC', 'اختر هيئة التقوم التي تريد');
@define('REPLY', 'رد');
@define('USERCONF_GROUPS', 'مجموعة الاعضاء');
@define('USERCONF_GROUPS_DESC', 'هذا العضو لدية عضوية في هذه المجموعات. تعدد العضويه في مجموعات مختلفة ممكن');
@define('MANAGE_GROUPS', 'ادارة المجموعات');
@define('DELETED_GROUP', 'تم حذفها #%d %s المجموعة');
@define('CREATED_GROUP', 'تم انشاءها %s المجموعة الجديدة');
@define('MODIFIED_GROUP', 'تم تغييرها %s خصائص المجموعة');
@define('GROUP', 'المجموعات');
@define('CREATE_NEW_GROUP', 'انشاء مجموعة جديدة');
@define('DELETE_GROUP', 'هل انت متأكد من حذف المجموعة  #%d %s');
@define('USERLEVEL_OBSOLETE', 'ملاحظة: خاصية مستوى المستخدم الآن تتناسق مع ملفات الحث والصلاحيات.و ميزات المستخدم الآن يتم معالجتها مع عضوية المجموعة ! ! ! ');
@define('SYNDICATION_PLUGIN_FEEDBURNERID', 'FeedBurner ID');
@define('SYNDICATION_PLUGIN_FEEDBURNERID_DESC', 'The ID of the feed you wish to publish');
@define('SYNDICATION_PLUGIN_FEEDBURNERIMG', 'FeedBurner image');
@define('SYNDICATION_PLUGIN_FEEDBURNERIMG_DESC', 'Name of image to display (or leave blank for counter), located on feedburner.com, ex: fbapix.gif');
@define('SYNDICATION_PLUGIN_FEEDBURNERTITLE', 'FeedBurner title');
@define('SYNDICATION_PLUGIN_FEEDBURNERTITLE_DESC', 'Title (if any) to display alongside the image');
@define('SYNDICATION_PLUGIN_FEEDBURNERALT', 'FeedBurner image text');
@define('SYNDICATION_PLUGIN_FEEDBURNERALT_DESC', 'Text (if any) to display when hovering the image');
@define('INSTALL_DBPORT', 'منفذ قاعدة البيانات');
@define('INSTALL_DBPORT_DESC', 'منفذ الاتصال بسيرفر قاعدة البيانات');
@define('PLUGIN_GROUP_FRONTEND_EXTERNAL_SERVICES', 'موجه إلى سيرف خارجي');
@define('PLUGIN_GROUP_FRONTEND_FEATURES', 'ملامح التوجية');
@define('PLUGIN_GROUP_FRONTEND_FULL_MODS', 'Frontend: Full Mods');
@define('PLUGIN_GROUP_FRONTEND_VIEWS', 'Frontend: مشاهدة');
@define('PLUGIN_GROUP_FRONTEND_ENTRY_RELATED', 'Frontend: Entry Related');
@define('PLUGIN_GROUP_BACKEND_EDITOR', 'Backend: محرر');
@define('PLUGIN_GROUP_BACKEND_USERMANAGEMENT', 'Backend: Usermanagement');
@define('PLUGIN_GROUP_BACKEND_METAINFORMATION', 'Backend: Meta information');
@define('PLUGIN_GROUP_BACKEND_TEMPLATES', 'Backend: قوالب');
@define('PLUGIN_GROUP_BACKEND_FEATURES', 'Backend: ملامح');
@define('PLUGIN_GROUP_IMAGES', 'صور');
@define('PLUGIN_GROUP_ANTISPAM', 'مقاومة السبام');
@define('PLUGIN_GROUP_MARKUP', 'مؤشر عليها');
@define('PLUGIN_GROUP_STATISTICS', 'إحصائيات');
@define('PERMISSION_PERSONALCONFIGURATION', 'personalConfiguration: Access personal configuration');
@define('PERMISSION_PERSONALCONFIGURATIONUSERLEVEL', 'personalConfigurationUserlevel: Change userlevels');
@define('PERMISSION_PERSONALCONFIGURATIONNOCREATE', 'personalConfigurationNoCreate: Change "forbid creating entries"');  
@define('PERMISSION_PERSONALCONFIGURATIONRIGHTPUBLISH', 'personalConfigurationRightPublish: Change right to publish entries');
@define('PERMISSION_SITECONFIGURATION', 'siteConfiguration: Access system configuration');
@define('PERMISSION_BLOGCONFIGURATION', 'blogConfiguration: Access blog-centric configuration');
@define('PERMISSION_ADMINENTRIES', 'adminEntries: Administrate entries');
@define('PERMISSION_ADMINENTRIESMAINTAINOTHERS', 'adminEntriesMaintainOthers: Administrate other user\'s entries');
@define('PERMISSION_ADMINIMPORT', 'adminImport: Import entries');
@define('PERMISSION_ADMINCATEGORIES', 'adminCategories: Administrate categories');
@define('PERMISSION_ADMINCATEGORIESMAINTAINOTHERS', 'adminCategoriesMaintainOthers: Administrate other user\'s categories');
@define('PERMISSION_ADMINCATEGORIESDELETE', 'adminCategoriesDelete: Delete categories');
@define('PERMISSION_ADMINUSERS', 'adminUsers: Administrate users');
@define('PERMISSION_ADMINUSERSDELETE', 'adminUsersDelete: Delete users');
@define('PERMISSION_ADMINUSERSEDITUSERLEVEL', 'adminUsersEditUserlevel: Change userlevel');
@define('PERMISSION_ADMINUSERSMAINTAINSAME', 'adminUsersMaintainSame: Administrate users that are in your group(s)');
@define('PERMISSION_ADMINUSERSMAINTAINOTHERS', 'adminUsersMaintainOthers: Administrate users that are not in your group(s)');
@define('PERMISSION_ADMINUSERSCREATENEW', 'adminUsersCreateNew: أنشاء مستخدم جديد');
@define('PERMISSION_ADMINUSERSGROUPS', 'adminUsersGroups: Administrate usergroups');
@define('PERMISSION_ADMINPLUGINS', 'adminPlugins: Administrate plugins');
@define('PERMISSION_ADMINPLUGINSMAINTAINOTHERS', 'adminPluginsMaintainOthers: Administrate other user\'s plugins');
@define('PERMISSION_ADMINIMAGES', 'adminImages: Administrate media files');
@define('PERMISSION_ADMINIMAGESDIRECTORIES', 'adminImagesDirectories: Administrate media directories');
@define('PERMISSION_ADMINIMAGESADD', 'adminImagesAdd: Add new media files');
@define('PERMISSION_ADMINIMAGESDELETE', 'adminImagesDelete: Delete media files');
@define('PERMISSION_ADMINIMAGESMAINTAINOTHERS', 'adminImagesMaintainOthers: Administrate other user\'s media files');
@define('PERMISSION_ADMINIMAGESVIEW', 'adminImagesView: View media files');
@define('PERMISSION_ADMINIMAGESSYNC', 'adminImagesSync: Sync thumbnails');
@define('PERMISSION_ADMINCOMMENTS', 'adminComments: Administrate comments');
@define('PERMISSION_ADMINTEMPLATES', 'adminTemplates: Administrate templates');
@define('INSTALL_BLOG_EMAIL', 'عنوان بريد المجلة');
@define('INSTALL_BLOG_EMAIL_DESC', 'هذا إعداد البريد الإلكتروني الذي سوف تصل عليه الرسائل في حال قام الزائر بمراسلة إدارة المجلة. يجب عليك أن تتأكد من أن هذا البريد صحيح و إن كان من قبل استضافتك أن يكون معرف في إدارة بريد الاستضافة ، حيث من الممكن لو لم يكن بريد معرف أن يرفض صدور المراسلات من المجلة');
@define('CATEGORIES_PARENT_BASE', 'فقط أعرض الأقسام في الأسفل');
@define('CATEGORIES_PARENT_BASE_DESC', 'You can choose a parent category so that only the child categories are shown.');
@define('CATEGORIES_HIDE_PARALLEL', 'أخفاء الأقسام التي ليست من ضمن شجرة التصنيف');
@define('CATEGORIES_HIDE_PARALLEL_DESC', 'If you want to hide categories that are part of a different category tree, you need to enable this. This feature makes most sense if used in conjunction with a multi-blog using the "Properties/Templates of categories" plugin.');
@define('PERMISSION_ADMINIMAGESVIEWOTHERS', 'adminImagesViewOthers: View other user\'s media files');
@define('CHARSET_NATIVE', 'محلي');
@define('INSTALL_CHARSET', 'ترميز الأحرف');
@define('INSTALL_CHARSET_DESC', ' هنا يمكن لك  أن تغير بين الترميز العالمي UTF-8 و الترميز المحلي للغتك مثل ترميز (ISO, EUC, ...)  ، بعض اللغات لديها فقط ترجمة ترميز UTF-8  لذلك باختياريك ترميز لغتك المحلية لن يكون له أثر على أداء مدونتك ، نقترح استخدام UTF-8 للتركيب الجديد. أحذر . . .أحذر . . . أحذر . . .  لا تقم بتغيير الترميز إذا كنت كتبت مواضيع من قبل. لأن ما كتبته بترميز لغة أخرى سوف يصبح على شكل طلاسم. أتجه إلى هذا الموقع http://www.s9y.org/index.php?node=46   للاطلاع على المزيد من المعلومات');
@define('CALENDAR_ENABLE_EXTERNAL_EVENTS', 'Enable Plugin API hook');
@define('CALENDAR_EXTEVENT_DESC', 'If enabled, plugins can hook into the calendar to display their own events highlighted. Only enable if you have installed plugins that need this, otherwise it just decreases performance.');
@define('XMLRPC_NO_LONGER_BUNDLED', 'The XML-RPC API Interface to Serendipity is no longer bundled because of ongoing security issues with this API and not many people using it. Thus you need to install the XML-RPC Plugin to use the XML-RPC API. The URL to use in your applications will NOT change - as soon as you have installed the plugin, you will again be able to use the API.');
@define('PERM_READ', 'قراءة التصريح');
@define('PERM_WRITE', 'كتابة التصريح');

@define('PERM_DENIED', 'تجاهل التصريح');
@define('INSTALL_ACL', 'طبق تصريح القراءة لى الأقسام');
@define('INSTALL_ACL_DESC', 'If enabled, the usergroup permission settings you setup for categories will be applied when logged-in users view your blog. If disabled, the read-permissions of the categories are NOT applied, but the positive effect is a little speedup on your blog. So if you don\'t need multi-user read permissions for your blog, disable this setting.');
@define('PLUGIN_API_VALIDATE_ERROR', 'خيارات هيئة جمل الخطأ "%s". تحتاج إلى أنواع المحتويات "%s".');
@define('USERCONF_CHECK_PASSWORD', 'كلمة المرور القديمة');
@define('USERCONF_CHECK_PASSWORD_DESC', 'أن غيرة كلمة المرور في الحقل السابق ، فأنه يجب أن تدخل كلمة المرور الحالية في هذا الحقل');
@define('USERCONF_CHECK_PASSWORD_ERROR', 'لم تدخل كلمة المرور الصحيحة الحالية .لذلك ليس من صلاحياتك تغيير كلمة المرور الى كلمة جيدة. ! ! ! تنبيه: لم يتم حفظ التغييرات');
@define('ERROR_XSRF', 'Your browser did not sent a valid HTTP-Referrer string. This may have either been caused by a misconfigured browser/proxy or by a Cross Site Request Forgery (XSRF) aimed at you. The action you requested could not be completed.');
@define('AUTHORS', 'المحررين');
@define('AUTHORS_ALLOW_SELECT', 'السماح للزوار بعرض عدة كتاب كل مرة؟');
@define('AUTHORS_ALLOW_SELECT_DESC', 'If this option is enabled, a checkbox will be put next to each author in this sidebar plugin.  Users can check those boxes and see entries matching their selection.');
@define('AUTHOR_PLUGIN_DESC', 'أعرض قائمة بأسماء الكتاب');
@define('CATEGORY_PLUGIN_TEMPLATE', 'Enable Smarty-Templates?');
@define('CATEGORY_PLUGIN_TEMPLATE_DESC', 'If this option is enabled, the plugin will utilize Smarty-Templating features to output the category listing. If you enable this, you can change the layout via the "plugin_categories.tpl" template file. Enabling this option will impact performance, so if you do not need to make customizations, leave it disabled.');
@define('CATEGORY_PLUGIN_SHOWCOUNT', 'أعرض عدد المواضيع لك تصنيف؟');
@define('AUTHORS_SHOW_ARTICLE_COUNT', 'أعرض عدد مواضيع الكاتب بجانب أسمه؟');
@define('AUTHORS_SHOW_ARTICLE_COUNT_DESC', 'في حال تشغيل هذا الخيار فإن عدد المواضيع الخاصة بهذا الكاتب سوف يتم عرضها بجانب إسمه');
@define('INSTALL_PERMALINK_COMMENTSPATH', 'Path to comments');
@define('PERM_SET_CHILD', 'Set the same permissions on all child directories');
@define('PERMISSION_FORBIDDEN_PLUGINS', 'Forbidden plugins');
@define('PERMISSION_FORBIDDEN_HOOKS', 'Forbidden events');
@define('PERMISSION_FORBIDDEN_ENABLE', 'Enable Plugin ACL for usergroups?');
@define('PERMISSION_FORBIDDEN_ENABLE_DESC', 'If the option "Plugin ACL for usergroups" is enabled in the configuration, you can specify which usergroups are allowed to execute certain plugins/events.');
@define('DELETE_SELECTED_ENTRIES', 'Delete selected entries');
@define('PLUGIN_AUTHORS_MINCOUNT', 'Show only authors with at least X articles');
@define('FURTHER_LINKS_S9Y_BOOKMARKLET', 'Bookmarklet');
@define('FURTHER_LINKS_S9Y_BOOKMARKLET_DESC', 'Bookmark this link and then use it on any page you want to blog about to quickly access your Serendipity Blog.');
@define('IMPORT_WP_PAGES', 'Also fetch attachments and staticpages as normal blog entries?');
@define('USERCONF_CREATE', 'Disable user / forbid activity?');
@define('USERCONF_CREATE_DESC', 'If selected, the user will not have any editing or creation possibilities on the blog anymore. When logging in to the backend, he cannot do anything else apart from logging out and viewing his personal configuration.');
@define('CATEGORY_HIDE_SUB', 'Hide postings made to sub-categories?');
@define('CATEGORY_HIDE_SUB_DESC', 'By default, when you browse a category also entries of any subcategory are displayed. If this option is turned on, only postings of the currently selected category are displayed.');
@define('PINGBACK_SENDING', 'Sending pingback to URI %s...');
@define('PINGBACK_SENT', 'Pingback successful');
@define('PINGBACK_FAILED', 'Pingback failed: %s');
@define('PINGBACK_NOT_FOUND', 'No pingback-URI found.');
@define('CATEGORY_PLUGIN_HIDEZEROCOUNT', 'Hide archives link when no entries were made in that timespan (requires counting entries)');
@define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS import, requires PHP5 and might take up much memory');
